@@ -310,8 +310,10 @@ getRMSFolder = function(myfolder,
                         summaryFun = 'mean',
                         verbose = TRUE) {
   time_start = proc.time()  # timing
-  filenames = list.files(myfolder, pattern = "*.wav|.mp3", full.names = TRUE)
-  if (length(filenames) < 1) stop('No audio files to analyze')
+  filenames = list.files(myfolder, pattern = "*.wav|.mp3|.WAV|.MP3", full.names = TRUE)
+  if (length(filenames) < 1) {
+    stop(paste('No wav/mp3 files found in', myfolder))
+  }
   # in order to provide more accurate estimates of time to completion,
   # check the size of all files in the target folder
   filesizes = file.info(filenames)$size
@@ -333,7 +335,7 @@ getRMSFolder = function(myfolder,
 
   # prepare output
   if (summary == TRUE) {
-    output = data.frame(sound = basename(filenames))
+    output = data.frame(file = basename(filenames))
     for (s in 1:length(summaryFun)) {
       # for each summary function...
       f = eval(parse(text = summaryFun[s]))
@@ -409,7 +411,10 @@ normalizeFolder = function(myfolder,
                            savepath = NULL,
                            verbose = TRUE) {
   time_start = proc.time()  # timing
-  filenames = list.files(myfolder, pattern = "*.wav|.mp3", full.names = TRUE)
+  filenames = list.files(myfolder, pattern = "*.wav|.mp3|.WAV|.MP3", full.names = TRUE)
+  if (length(filenames) < 1) {
+    stop(paste('No wav/mp3 files found in', myfolder))
+  }
   # in order to provide more accurate estimates of time to completion,
   # check the size of all files in the target folder
   n = length(filenames)
