@@ -448,8 +448,10 @@ generateHarmonics = function(pitch,
                              rolloffDriftDep = 3,
                              randomWalk_trendStrength = .5,
                              shortestEpoch = 300,
+                             subRatio = 1,
                              subFreq = 100,
                              subDep = 0,
+                             subWidth = 10000,
                              ampl = NA,
                              normalize = TRUE,
                              interpol = c('approx', 'spline', 'loess')[3],
@@ -471,7 +473,7 @@ generateHarmonics = function(pitch,
             anchors = old,
             len = lp,
             valueFloor = permittedValues[p, 'low'],
-            valueCeiling = permittedValues[p, 'high'],
+            valueCeiling = Inf,  # permittedValues[p, 'high'],
             interpol = interpol)
           assign(p, new)
         }
@@ -495,7 +497,8 @@ generateHarmonics = function(pitch,
   # vectorized par-s should be upsampled and converted from ms to gc scale
   update_pars = c(
     'rolloff', 'rolloffOct', 'rolloffParab', 'rolloffParabHarm', 'rolloffKHz',
-    'jitterDep', 'jitterLen', 'shimmerDep', 'shimmerLen', 'subFreq', 'subDep'
+    'jitterDep', 'jitterLen', 'shimmerDep', 'shimmerLen',
+    'subRatio', 'subFreq', 'subDep', 'subWidth'
   )
   for (p in update_pars) {
     old = get(p)
@@ -700,8 +703,10 @@ generateHarmonics = function(pitch,
     vocalFry = getVocalFry(
       rolloff = rolloff_source,
       pitch_per_gc = pitch_per_gc,
+      subRatio = subRatio,
       subFreq = subFreq * rw ^ subDriftDep,
       subDep = subDep * rw ^ subDriftDep * vocalFry_on,
+      subWidth = subWidth * rw ^ subDriftDep,
       shortestEpoch = shortestEpoch,
       dynamicRange = dynamicRange
     )
