@@ -479,7 +479,9 @@ spectrogram = function(
 #' and/or .mp3 files (e.g. Firefox or Chrome), you can view the spetrograms and
 #' click on them to play each sound. Unlike \code{\link{analyzeFolder}},
 #' spectrogramFolder supports plotting both a spectrogram and an oscillogram if
-#' \code{osc = TRUE}.
+#' \code{osc = TRUE}. The default approximate width of images in html (flexbox)
+#' is determined by the \code{width} parameter (ie it is the same as the width
+#' of png images, in pixels).
 #' @inheritParams spectrogram
 #' @inheritParams analyzeFolder
 #' @param myfolder full path to the folder containing wav/mp3 files
@@ -514,7 +516,10 @@ spectrogramFolder = function(myfolder,
                              res = NA,
                              ...) {
   time_start = proc.time()  # timing
-  filenames = list.files(myfolder, pattern = "*.wav|.mp3", full.names = TRUE)
+  filenames = list.files(myfolder, pattern = "*.wav|.mp3|.WAV|.MP3", full.names = TRUE)
+  if (length(filenames) < 1) {
+    stop(paste('No wav/mp3 files found in', myfolder))
+  }
   # in order to provide more accurate estimates of time to completion,
   # check the size of all files in the target folder
   filesizes = file.info(filenames)$size
@@ -545,7 +550,7 @@ spectrogramFolder = function(myfolder,
     }
   }
   if (htmlPlots) {
-    htmlPlots(myfolder, myfiles = filenames)
+    htmlPlots(myfolder, myfiles = filenames, width = paste0(width, units))
   }
 }
 
