@@ -8,10 +8,10 @@ ui = fluidPage(
                                   tabPanel("Syllables",
                                            sidebarLayout(
                                              sidebarPanel(
-                                               sliderInput('sylLen', 'Syllable length, ms', value=permittedValues['sylLen','default'], min=permittedValues['sylLen', 'low'], max=permittedValues['sylLen', 'high'], step=permittedValues['sylLen','step']),
-                                               sliderInput('nSyl', 'Number of syllables', value=permittedValues['nSyl','default'], min=permittedValues['nSyl', 'low'], max=permittedValues['nSyl', 'high'], step=permittedValues['nSyl','step']),
-                                               sliderInput('pauseLen', 'Pause, ms', value=permittedValues['pauseLen','default'], min=permittedValues['pauseLen', 'low'], max=permittedValues['pauseLen', 'high'], step=permittedValues['pauseLen','step']),
-                                               sliderInput('repeatBout', 'Repeat bout # times', value=permittedValues['repeatBout','default'], min=permittedValues['repeatBout', 'low'], max=permittedValues['repeatBout', 'high'], step=permittedValues['repeatBout','step']),
+                                               sliderInput('sylLen', 'Syllable length, ms ("sylLen")', value=permittedValues['sylLen','default'], min=permittedValues['sylLen', 'low'], max=permittedValues['sylLen', 'high'], step=permittedValues['sylLen','step']),
+                                               sliderInput('nSyl', 'Number of syllables ("nSyl")', value=permittedValues['nSyl','default'], min=permittedValues['nSyl', 'low'], max=permittedValues['nSyl', 'high'], step=permittedValues['nSyl','step']),
+                                               sliderInput('pauseLen', 'Pause, ms ("pauseLen")', value=permittedValues['pauseLen','default'], min=permittedValues['pauseLen', 'low'], max=permittedValues['pauseLen', 'high'], step=permittedValues['pauseLen','step']),
+                                               sliderInput('repeatBout', 'Repeat bout # times ("repeatBout")', value=permittedValues['repeatBout','default'], min=permittedValues['repeatBout', 'low'], max=permittedValues['repeatBout', 'high'], step=permittedValues['repeatBout','step']),
                                                width=6
                                              ),
                                              mainPanel(
@@ -24,9 +24,9 @@ ui = fluidPage(
                                   tabPanel("Hypers",
                                            sidebarLayout(
                                              sidebarPanel(
-                                               sliderInput('temperature', 'Temperature', value=permittedValues['temperature','default'], min=permittedValues['temperature', 'low'], max=permittedValues['temperature', 'high'], step=permittedValues['temperature','step']),
-                                               sliderInput('maleFemale', 'Male-female *hyper*', value=permittedValues['maleFemale','default'], min=permittedValues['maleFemale', 'low'], max=permittedValues['maleFemale', 'high'], step=permittedValues['maleFemale','step']),
-                                               sliderInput('creakyBreathy', 'Creaky-breathy *hyper*', value=permittedValues['creakyBreathy','default'], min=permittedValues['creakyBreathy', 'low'], max=permittedValues['creakyBreathy', 'high'], step=permittedValues['creakyBreathy','step']),
+                                               sliderInput('temperature', 'Temperature ("temperature")', value=permittedValues['temperature','default'], min=permittedValues['temperature', 'low'], max=permittedValues['temperature', 'high'], step=permittedValues['temperature','step']),
+                                               sliderInput('maleFemale', 'Male-female *hyper* ("maleFemale")', value=permittedValues['maleFemale','default'], min=permittedValues['maleFemale', 'low'], max=permittedValues['maleFemale', 'high'], step=permittedValues['maleFemale','step']),
+                                               sliderInput('creakyBreathy', 'Creaky-breathy *hyper* ("creakyBreathy")', value=permittedValues['creakyBreathy','default'], min=permittedValues['creakyBreathy', 'low'], max=permittedValues['creakyBreathy', 'high'], step=permittedValues['creakyBreathy','step']),
                                                width=6
                                              ),
                                              mainPanel(
@@ -39,11 +39,11 @@ ui = fluidPage(
                                   tabPanel("Settings",
                                            sidebarLayout(
                                              sidebarPanel(
-                                               numericInput('samplingRate', 'Sampling rate, Hz', value=permittedValues['samplingRate','default'], min=permittedValues['samplingRate', 'low'], max=permittedValues['samplingRate', 'high'], step=permittedValues['samplingRate','step']),
-                                               numericInput('windowLength', 'FFT window length, ms', value=permittedValues['windowLength','default'], min=permittedValues['windowLength', 'low'], max=permittedValues['windowLength', 'high'], step=permittedValues['windowLength','step']),
-                                               numericInput('pitchSamplingRate', 'Pitch sampling rate, Hz', value=permittedValues['pitchSamplingRate', 'default'], min=permittedValues['pitchSamplingRate', 'low'], max=permittedValues['pitchSamplingRate', 'high'], step=permittedValues['pitchSamplingRate', 'step']),
-                                               numericInput('dynamicRange', 'Dynamic range, dB', value=permittedValues['dynamicRange', 'default'], min=permittedValues['dynamicRange', 'low'], max=permittedValues['dynamicRange', 'high'], step=permittedValues['dynamicRange', 'step']),
-                                               sliderInput('pitchFloorCeiling', 'Synthesized pitch range, Hz', value=c(permittedValues['pitch', 'low'], permittedValues['pitch', 'high']), min=1, max=8000, step=10),
+                                               numericInput('samplingRate', 'Sampling rate, Hz ("samplingRate")', value=permittedValues['samplingRate','default'], min=permittedValues['samplingRate', 'low'], max=permittedValues['samplingRate', 'high'], step=permittedValues['samplingRate','step']),
+                                               numericInput('windowLength', 'FFT window length, ms ("windowLength")', value=permittedValues['windowLength','default'], min=permittedValues['windowLength', 'low'], max=permittedValues['windowLength', 'high'], step=permittedValues['windowLength','step']),
+                                               numericInput('pitchSamplingRate', 'Pitch sampling rate, Hz ("pitchSamplingRate")', value=permittedValues['pitchSamplingRate', 'default'], min=permittedValues['pitchSamplingRate', 'low'], max=permittedValues['pitchSamplingRate', 'high'], step=permittedValues['pitchSamplingRate', 'step']),
+                                               numericInput('dynamicRange', 'Dynamic range, dB ("dynamicRange")', value=permittedValues['dynamicRange', 'default'], min=permittedValues['dynamicRange', 'low'], max=permittedValues['dynamicRange', 'high'], step=permittedValues['dynamicRange', 'step']),
+                                               sliderInput('pitchFloorCeiling', 'Synthesized pitch range, Hz ("pitchFloorCeiling")', value=c(permittedValues['pitch', 'low'], permittedValues['pitch', 'high']), min=1, max=8000, step=10),
                                                width=6
                                              ),
                                              mainPanel(
@@ -84,8 +84,8 @@ ui = fluidPage(
                                   tabPanel("Vibrato",
                                            sidebarLayout(
                                              sidebarPanel(
-                                               sliderInput('vibratoFreq', 'Vibrato rate, Hz', value=permittedValues['vibratoFreq','default'], min=permittedValues['vibratoFreq', 'low'], max=permittedValues['vibratoFreq', 'high'], step=permittedValues['vibratoFreq','step']),
-                                               sliderInput('vibratoDep', 'Vibrato depth, semitones', value=permittedValues['vibratoDep','default'], min=permittedValues['vibratoDep', 'low'], max=permittedValues['vibratoDep', 'high'], step=permittedValues['vibratoDep','step']),
+                                               sliderInput('vibratoFreq', 'Vibrato rate, Hz ("vibratoFreq")', value=permittedValues['vibratoFreq','default'], min=permittedValues['vibratoFreq', 'low'], max=permittedValues['vibratoFreq', 'high'], step=permittedValues['vibratoFreq','step']),
+                                               sliderInput('vibratoDep', 'Vibrato depth, semitones ("vibratoDep")', value=permittedValues['vibratoDep','default'], min=permittedValues['vibratoDep', 'low'], max=permittedValues['vibratoDep', 'high'], step=permittedValues['vibratoDep','step']),
                                                width=6
                                              ),
                                              mainPanel(
@@ -100,7 +100,7 @@ ui = fluidPage(
                                   tabPanel("Amplitude syllable",
                                            sidebarLayout(
                                              sidebarPanel(
-                                               sliderInput ('attackLen', 'Attack length, ms', value=permittedValues['attackLen','default'], min=permittedValues['attackLen', 'low'], max=permittedValues['attackLen', 'high'], step=permittedValues['attackLen','step']),
+                                               sliderInput ('attackLen', 'Attack length, ms ("attackLen")', value=permittedValues['attackLen','default'], min=permittedValues['attackLen', 'low'], max=permittedValues['attackLen', 'high'], step=permittedValues['attackLen','step']),
                                                actionButton(inputId = "ampl_syl_flatten", label = "Flatten amplitude envelope"),
                                                tableOutput("ampl_syl_anchors"), width=6
                                              ),
@@ -125,9 +125,9 @@ ui = fluidPage(
                                   tabPanel("Amplitude modulation",
                                            sidebarLayout(
                                              sidebarPanel(
-                                               sliderInput('amDep', 'AM depth', value=permittedValues['amDep','default'], min=permittedValues['amDep', 'low'], max=permittedValues['amDep', 'high'], step=permittedValues['amDep','step']),
-                                               sliderInput('amFreq', 'AM frequency, Hz', value=permittedValues['amFreq','default'], min=permittedValues['amFreq', 'low'], max=permittedValues['amFreq', 'high'], step=permittedValues['amFreq','step']),
-                                               sliderInput('amShape', 'AM shape', value=permittedValues['amShape','default'], min=permittedValues['amShape', 'low'], max=permittedValues['amShape', 'high'], step=permittedValues['amShape','step']),
+                                               sliderInput('amDep', 'AM depth ("amDep")', value=permittedValues['amDep','default'], min=permittedValues['amDep', 'low'], max=permittedValues['amDep', 'high'], step=permittedValues['amDep','step']),
+                                               sliderInput('amFreq', 'AM frequency, Hz ("amFreq")', value=permittedValues['amFreq','default'], min=permittedValues['amFreq', 'low'], max=permittedValues['amFreq', 'high'], step=permittedValues['amFreq','step']),
+                                               sliderInput('amShape', 'AM shape ("amShape")', value=permittedValues['amShape','default'], min=permittedValues['amShape', 'low'], max=permittedValues['amShape', 'high'], step=permittedValues['amShape','step']),
                                                width=6
                                              ),
                                              mainPanel(
@@ -142,13 +142,13 @@ ui = fluidPage(
                                   tabPanel("Glottal",
                                            sidebarLayout(
                                              sidebarPanel(
-                                               sliderInput('rolloff', 'Source rolloff, dB/octave', value=permittedValues['rolloff','default'], min=permittedValues['rolloff', 'low'], max=permittedValues['rolloff', 'high'], step=permittedValues['rolloff','step']),
+                                               sliderInput('rolloff', 'Source rolloff, dB/octave ("rolloff")', value=permittedValues['rolloff','default'], min=permittedValues['rolloff', 'low'], max=permittedValues['rolloff', 'high'], step=permittedValues['rolloff','step']),
                                                shinyBS::bsCollapsePanel("Advanced",
-                                                                        sliderInput('rolloffOct', 'Change of rolloff with frequency, dB/octave', value=permittedValues['rolloffOct','default'], min=permittedValues['rolloffOct', 'low'], max=permittedValues['rolloffOct', 'high'], step=permittedValues['rolloffOct','step']),
-                                                                        sliderInput('rolloffKHz', 'Adjust rolloff per f0,  dB/kHz', value=permittedValues['rolloffKHz','default'], min=permittedValues['rolloffKHz', 'low'], max=permittedValues['rolloffKHz', 'high'], step=permittedValues['rolloffKHz','step']),
-                                                                        sliderInput('rolloffParab', 'Parabolic rolloff adjustment, dB/octave', value=permittedValues['rolloffParab','default'], min=permittedValues['rolloffParab', 'low'], max=permittedValues['rolloffParab', 'high'], step=permittedValues['rolloffParab','step']),
-                                                                        sliderInput('rolloffParabHarm', 'Harmonics boosted', value=permittedValues['rolloffParabHarm','default'], min=permittedValues['rolloffParabHarm', 'low'], max=permittedValues['rolloffParabHarm', 'high'], step=permittedValues['rolloffParabHarm','step']),
-                                                                        sliderInput('glottis', 'Closed glottis, %', value=permittedValues['glottis', 'default'], min=permittedValues['glottis', 'low'], max=permittedValues['glottis', 'high'], step=permittedValues['glottis','step'])
+                                                                        sliderInput('rolloffOct', 'Change of rolloff with frequency, dB/octave ("rolloffOct")', value=permittedValues['rolloffOct','default'], min=permittedValues['rolloffOct', 'low'], max=permittedValues['rolloffOct', 'high'], step=permittedValues['rolloffOct','step']),
+                                                                        sliderInput('rolloffKHz', 'Adjust rolloff per f0,  dB/kHz ("rolloffKHz")', value=permittedValues['rolloffKHz','default'], min=permittedValues['rolloffKHz', 'low'], max=permittedValues['rolloffKHz', 'high'], step=permittedValues['rolloffKHz','step']),
+                                                                        sliderInput('rolloffParab', 'Parabolic rolloff adjustment, dB/octave ("rolloffParab")', value=permittedValues['rolloffParab','default'], min=permittedValues['rolloffParab', 'low'], max=permittedValues['rolloffParab', 'high'], step=permittedValues['rolloffParab','step']),
+                                                                        sliderInput('rolloffParabHarm', 'Harmonics boosted ("rolloffParabHarm")', value=permittedValues['rolloffParabHarm','default'], min=permittedValues['rolloffParabHarm', 'low'], max=permittedValues['rolloffParabHarm', 'high'], step=permittedValues['rolloffParabHarm','step']),
+                                                                        sliderInput('glottis', 'Closed glottis, % ("glottis")', value=permittedValues['glottis', 'default'], min=permittedValues['glottis', 'low'], max=permittedValues['glottis', 'high'], step=permittedValues['glottis','step'])
                                                ), width=6
                                              ),
                                              mainPanel(
@@ -160,15 +160,18 @@ ui = fluidPage(
                                   tabPanel("Nonlinear effects",
                                            sidebarLayout(
                                              sidebarPanel(
-                                               sliderInput('nonlinBalance', 'Balance between nonlinear regimes, %', value=permittedValues['nonlinBalance','default'], min=permittedValues['nonlinBalance', 'low'], max=permittedValues['nonlinBalance', 'high'], step=permittedValues['nonlinBalance','step']),
-                                               sliderInput('shortestEpoch', 'Shortest epoch length', value=permittedValues['shortestEpoch','default'], min=permittedValues['shortestEpoch', 'low'], max=permittedValues['shortestEpoch', 'high'], step=permittedValues['shortestEpoch','step']),
-                                               shinyBS::bsCollapsePanel("Advanced",
-                                                                        sliderInput('subFreq', 'Target subharmonic frequency, Hz', value=permittedValues['subFreq','default'], min=permittedValues['subFreq', 'low'], max=permittedValues['subFreq', 'high'], step=permittedValues['subFreq','step']),
-                                                                        sliderInput('subDep', 'Width of sidebands, Hz', value=permittedValues['subDep','default'], min=permittedValues['subDep', 'low'], max=permittedValues['subDep', 'high'], step=permittedValues['subDep','step']),
-                                                                        sliderInput('jitterDep', 'Jitter depth, semitones', value=permittedValues['jitterDep','default'], min=permittedValues['jitterDep', 'low'], max=permittedValues['jitterDep', 'high'], step=permittedValues['jitterDep','step']),
-                                                                        sliderInput('jitterLen', 'Jitter period, ms', value=permittedValues['jitterLen','default'], min=permittedValues['jitterLen', 'low'], max=permittedValues['jitterLen', 'high'], step=permittedValues['jitterLen','step']),
-                                                                        sliderInput('shimmerDep', 'Shimmer depth, %', value=permittedValues['shimmerDep','default'], min=permittedValues['shimmerDep', 'low'], max=permittedValues['shimmerDep', 'high'], step=permittedValues['shimmerDep','step']),
-                                                                        sliderInput('shimmerLen', 'Shimmer period, ms', value=permittedValues['shimmerLen','default'], min=permittedValues['shimmerLen', 'low'], max=permittedValues['shimmerLen', 'high'], step=permittedValues['shimmerLen','step'])
+                                               sliderInput('nonlinBalance', 'Balance between nonlinear regimes, % ("nonlinBalance")', value=permittedValues['nonlinBalance','default'], min=permittedValues['nonlinBalance', 'low'], max=permittedValues['nonlinBalance', 'high'], step=permittedValues['nonlinBalance','step']),
+                                               sliderInput('shortestEpoch', 'Shortest epoch length ("shortestEpoch")', value=permittedValues['shortestEpoch','default'], min=permittedValues['shortestEpoch', 'low'], max=permittedValues['shortestEpoch', 'high'], step=permittedValues['shortestEpoch','step']),
+                                               shinyBS::bsCollapsePanel("Subharmonics",
+                                                                        sliderInput('subRatio', 'Subharmonic frequency ratio ("subRatio")', value=permittedValues['subRatio','default'], min=permittedValues['subRatio', 'low'], max=permittedValues['subRatio', 'high'], step=permittedValues['subRatio','step']),
+                                                                        sliderInput('subFreq', 'Target subharmonic frequency, Hz (overrides number of subharmonics) ("subFreq")', value=permittedValues['subFreq','default'], min=permittedValues['subFreq', 'low'], max=permittedValues['subFreq', 'high'], step=permittedValues['subFreq','step']),
+                                                                        sliderInput('subDep', 'Depth of subharmonics, % ("subDep")', value=permittedValues['subDep','default'], min=permittedValues['subDep', 'low'], max=permittedValues['subDep', 'high'], step=permittedValues['subDep','step']),                                                                                                                                            sliderInput('subWidth', 'Width of sidebands, Hz ("subWidth")', value=permittedValues['subWidth','default'], min=permittedValues['subWidth', 'low'], max=permittedValues['subWidth', 'high'], step=permittedValues['subWidth','step'])
+                                               ),
+                                               shinyBS::bsCollapsePanel("Chaos",
+                                                                        sliderInput('jitterDep', 'Jitter depth, semitones ("jitterDep")', value=permittedValues['jitterDep','default'], min=permittedValues['jitterDep', 'low'], max=permittedValues['jitterDep', 'high'], step=permittedValues['jitterDep','step']),
+                                                                        sliderInput('jitterLen', 'Jitter period, ms ("jitterLen")', value=permittedValues['jitterLen','default'], min=permittedValues['jitterLen', 'low'], max=permittedValues['jitterLen', 'high'], step=permittedValues['jitterLen','step']),
+                                                                        sliderInput('shimmerDep', 'Shimmer depth, % ("shimmerDep")', value=permittedValues['shimmerDep','default'], min=permittedValues['shimmerDep', 'low'], max=permittedValues['shimmerDep', 'high'], step=permittedValues['shimmerDep','step']),
+                                                                        sliderInput('shimmerLen', 'Shimmer period, ms ("shimmerLen")', value=permittedValues['shimmerLen','default'], min=permittedValues['shimmerLen', 'low'], max=permittedValues['shimmerLen', 'high'], step=permittedValues['shimmerLen','step'])
                                                ), width=6
                                              ),
                                              mainPanel(
@@ -197,8 +200,8 @@ ui = fluidPage(
                                   tabPanel("Formants",
                                            sidebarLayout(
                                              sidebarPanel(
-                                               sliderInput('formantDep', 'Formant prominence *hyper*', value=permittedValues['formantDep','default'], min=permittedValues['formantDep', 'low'], max=permittedValues['formantDep', 'high'], step=permittedValues['formantDep','step']),
-                                               sliderInput('formantWidth', 'Formant width *hyper*', value=permittedValues['formantWidth','default'], min=permittedValues['formantWidth', 'low'], max=permittedValues['formantWidth', 'high'], step=permittedValues['formantWidth','step']),
+                                               sliderInput('formantDep', 'Formant prominence *hyper* ("formantDep")', value=permittedValues['formantDep','default'], min=permittedValues['formantDep', 'low'], max=permittedValues['formantDep', 'high'], step=permittedValues['formantDep','step']),
+                                               sliderInput('formantWidth', 'Formant width *hyper* ("formantWidth")', value=permittedValues['formantWidth','default'], min=permittedValues['formantWidth', 'low'], max=permittedValues['formantWidth', 'high'], step=permittedValues['formantWidth','step']),
                                                textInput('vowelString', label='String of vowel presets *hyper*', value = "a", width = NULL, placeholder ='uaaao'),
                                                shinyBS::bsCollapsePanel("Show & modify formants manually",
                                                                         tags$style(type="text/css", "textarea {width:100%}"), # NB: this little hack ties the width of the following textarea to the width of the panel in which it is embedded; see http://stackoverflow.com/questions/32640875/r-shiny-tie-textarea-width-to-wellpanel-width
@@ -206,10 +209,10 @@ ui = fluidPage(
                                                ),
                                                shinyBS::bsCollapsePanel("Advanced",
                                                                         checkboxInput(inputId = 'estimateVTL', label = 'Estimate vocal tract length from formants?', value = FALSE),
-                                                                        sliderInput('vocalTract', 'The length of vocal tract, cm', value=permittedValues['vocalTract', 'default'], min=permittedValues['vocalTract', 'low'], max=permittedValues['vocalTract', 'high'], step=permittedValues['vocalTract', 'step']),
-                                                                        sliderInput('formantDepStoch', 'Added formants, dB', value=permittedValues['formantDepStoch','default'], min=permittedValues['formantDepStoch', 'low'], max=permittedValues['formantDepStoch', 'high'], step=permittedValues['formantDepStoch','step']),
-                                                                        sliderInput('lipRad', 'Lip radiation, dB/oct', value=permittedValues['lipRad','default'], min=permittedValues['lipRad', 'low'], max=permittedValues['lipRad', 'high'], step=permittedValues['lipRad','step']),
-                                                                        sliderInput('noseRad', 'Nose radiation, dB/oct', value=permittedValues['noseRad','default'], min=permittedValues['noseRad', 'low'], max=permittedValues['noseRad', 'high'], step=permittedValues['noseRad','step'])
+                                                                        sliderInput('vocalTract', 'The length of vocal tract, cm ("vocalTract")', value=permittedValues['vocalTract', 'default'], min=permittedValues['vocalTract', 'low'], max=permittedValues['vocalTract', 'high'], step=permittedValues['vocalTract', 'step']),
+                                                                        sliderInput('formantDepStoch', 'Added formants, dB ("formantDepStoch")', value=permittedValues['formantDepStoch','default'], min=permittedValues['formantDepStoch', 'low'], max=permittedValues['formantDepStoch', 'high'], step=permittedValues['formantDepStoch','step']),
+                                                                        sliderInput('lipRad', 'Lip radiation, dB/oct ("lipRad")', value=permittedValues['lipRad','default'], min=permittedValues['lipRad', 'low'], max=permittedValues['lipRad', 'high'], step=permittedValues['lipRad','step']),
+                                                                        sliderInput('noseRad', 'Nose radiation, dB/oct ("noseRad")', value=permittedValues['noseRad','default'], min=permittedValues['noseRad', 'low'], max=permittedValues['noseRad', 'high'], step=permittedValues['noseRad','step'])
                                                ),
                                                width=6
                                              ),
@@ -240,8 +243,8 @@ ui = fluidPage(
                                            sidebarLayout(
                                              sidebarPanel(
                                                selectInput(inputId='noiseType', label="Presets", choices=c('Breathing'='b', 'Snuffling'='n', 'h'='h', 'sh'='x','f'='f', 's'='s'), selected='b'),
-                                               sliderInput('rolloffNoise', 'Linear noise rolloff, dB/oct', value=permittedValues['rolloffNoise','default'], min=permittedValues['rolloffNoise', 'low'], max=permittedValues['rolloffNoise', 'high'], step=permittedValues['rolloffNoise','step']),
-                                               sliderInput('rolloffNoiseExp', 'Exponential noise rolloff, dB/oct', value=permittedValues['rolloffNoiseExp','default'], min=permittedValues['rolloffNoiseExp', 'low'], max=permittedValues['rolloffNoiseExp', 'high'], step=permittedValues['rolloffNoiseExp','step']),
+                                               sliderInput('rolloffNoise', 'Linear noise rolloff, dB/oct ("rolloffNoise")', value=permittedValues['rolloffNoise','default'], min=permittedValues['rolloffNoise', 'low'], max=permittedValues['rolloffNoise', 'high'], step=permittedValues['rolloffNoise','step']),
+                                               sliderInput('rolloffNoiseExp', 'Exponential noise rolloff, dB/oct ("rolloffNoiseExp")', value=permittedValues['rolloffNoiseExp','default'], min=permittedValues['rolloffNoiseExp', 'low'], max=permittedValues['rolloffNoiseExp', 'high'], step=permittedValues['rolloffNoiseExp','step']),
                                                shinyBS::bsCollapsePanel("Show & modify formants manually",
                                                                         tags$style(type="text/css", "textarea {width:100%}"), # NB: this little hack ties the width of the following textarea to the width of the panel in which it is embedded; see http://stackoverflow.com/questions/32640875/r-shiny-tie-textarea-width-to-wellpanel-width
                                                                         tags$textarea(id="formantsNoise", label='Exact formants for unvoiced part', rows=10, cols=20, value="", placeholder ="list()")
